@@ -4,12 +4,17 @@ function index()
 	if not nixio.fs.access("/etc/config/aliyundrive-webdav") then
 		return
 	end
-	entry({"admin", "services", "aliyundrive-webdav"}, alias("admin", "services", "aliyundrive-webdav", "client"),_("AliyunDrive WebDAV"), 10).dependent = true  -- 首页
-	entry({"admin", "services", "aliyundrive-webdav", "client"}, cbi("aliyundrive-webdav/client"),_("Settings"), 10).leaf = true  -- 客户端配置
-	entry({"admin", "services", "aliyundrive-webdav", "log"}, form("aliyundrive-webdav/log"),_("Log"), 30).leaf = true -- 日志页面
 
-	entry({"admin", "services", "aliyundrive-webdav", "status"}, call("action_status")).leaf = true
-	entry({"admin", "services", "aliyundrive-webdav", "logtail"}, call("action_logtail")).leaf = true
+	local page
+	page = entry({"admin", "services", "aliyundrive-webdav"}, alias("admin", "services", "aliyundrive-webdav", "client"), _("AliyunDrive WebDAV"), 10) -- 首页
+	page.dependent = true
+	page.acl_depends = { "luci-app-aliyundrive-webdav" }
+
+	entry({"admin", "services", "aliyundrive-webdav", "client"}, cbi("aliyundrive-webdav/client"), _("Settings"), 10).leaf = true  -- 客户端配置
+	entry({"admin", "services", "aliyundrive-webdav", "log"}, form("aliyundrive-webdav/log"), _("Log"), 30).leaf = true -- 日志页面
+
+	entry({"admin", "services", "aliyundrive-webdav", "status"}, call("action_status")).leaf = true -- 运行状态
+	entry({"admin", "services", "aliyundrive-webdav", "logtail"}, call("action_logtail")).leaf = true -- 日志采集
 end
 
 function action_status()
